<?php    
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class RelTicketMedio  {

    protected $RelTicketMedio;
    protected $utilService;
    
    public function __construct(Services\RelTicketMedioService $RelTicketMedioService, Utilities\Util $utilService) {
        $this->RelTicketMedioService = $RelTicketMedioService;
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $conditions = $this->utilService->getParamsAsArray($request);
            $conditions = $this->buildParams($conditions);
            $result = $this->RelTicketMedioService->find($conditions, $conditions['IDRELATORIO']);
    
            $response->addDataSet(new DataSet("relTicketMedio", $result));
            return $response;
        }
        catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function buildParams($conditions){
        if(!array_key_exists('CDFILIAL', $conditions)) {
            $conditions['CDFILIAL'] = '';
            $conditions['TCDFILIAL'] = 'T';
        } else {
            if(is_array($conditions['CDFILIAL'])){
                $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
                $conditions['TCDFILIAL'] = '';
            }
            else{
                $conditions['CDFILIAL'] = '';
                $conditions['TCDFILIAL'] = 'T';
            }
        }
        if(!array_key_exists('CDLOJA', $conditions)) {
            $conditions['CDLOJA'] = '';
            $conditions['TCDLOJA'] = 'T';
        } else {
            $conditions['CDLOJA'] = implode('_', $conditions['CDLOJA']);
            $conditions['TCDLOJA'] = '';
        }
        if(!array_key_exists('CDCAIXA', $conditions)) {
            $conditions['CDCAIXA'] = '';
            $conditions['TCDCAIXA'] = 'T';
        } else {
            $conditions['CDCAIXA'] = implode('_', $conditions['CDCAIXA']);
            $conditions['TCDCAIXA'] = '';
        }
        if(array_key_exists('DTPERIODO', $conditions)) {
            $conditions['DTINI'] = $conditions['DTPERIODO'][0];
            $conditions['DTFIN'] = $conditions['DTPERIODO'][1];
            unset($conditions['DTPERIODO']);
        }
        
        return $conditions;
    }
    
}
