<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use \Zeedhi\Framework\Util\Functions;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services\RelatoriosSaldoConsumidorService;
use Teknisa\MAN\Utilities;
use \Exception as Exception;

class RelatoriosSaldoConsumidor {
    protected $RelatoriosSaldoConsumidorService;
    protected $utilService;

    public function __construct(RelatoriosSaldoConsumidorService $RelatoriosSaldoConsumidorService, Utilities\Util $utilService) {
        $this->RelatoriosSaldoConsumidorService = $RelatoriosSaldoConsumidorService;
        $this->utilService = $utilService;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];

        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->buildParamsSaldo($conditions);
        $result = $this->RelatoriosSaldoConsumidorService->find($conditions);
        $response->addDataSet(new DataSet("relSaldoConsumidor", $result));

        return $result;
    }

    
    public function buildParamsSaldo($conditions) {
        if(!Functions::arrayKeyExists('CDCONSUMIDOR', $conditions)) {
            $conditions['CDCONSUMIDOR'] = '';
            $conditions['TCDCONSUMIDOR'] = 'T';
        } else {
            $conditions['CDCONSUMIDOR'] = '_'.implode('_', $conditions['CDCONSUMIDOR']).'_';
            $conditions['TCDCONSUMIDOR'] = '';
        }

        if(!Functions::arrayKeyExists('CDTIPOCONS', $conditions)) {
            $conditions['CDTIPOCONS'] = '';
            $conditions['TCDTIPOCONS'] = 'T';
        } else {
            $conditions['CDTIPOCONS'] = '_'.implode('_', $conditions['CDTIPOCONS']).'_';
            $conditions['TCDTIPOCONS'] = '';
        }

        if(!Functions::arrayKeyExists('CDFAMILISALD', $conditions)) {
            $conditions['CDFAMILISALD'] = '';
            $conditions['TCDFAMILISALD'] = 'T';
        } else {
            $conditions['CDFAMILISALD'] = '_'.implode('_', $conditions['CDFAMILISALD']).'_';
            $conditions['TCDFAMILISALD'] = '';
        }

        if(Functions::arrayKeyExists('DTENTRVENDA', $conditions)) {
            $conditions['DTEXTRATOINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTEXTRATOFIN'] = $conditions['DTENTRVENDA'][1];

            unset($conditions['DTENTRVENDA']);
        }

        if(Functions::arrayKeyExists('CDFILIAL', $conditions)) {
            unset($conditions['CDFILIAL']);
        }

        if(Functions::arrayKeyExists('NRORG', $conditions)) {
            unset($conditions['NRORG']);
        }

        if(Functions::arrayKeyExists('NMRAZSOCCLIE', $conditions)) {
            unset($conditions['NMRAZSOCCLIE']);
        }

        return $conditions;
    }
}